@@ -125,11 +125,26 @@ sub clear_line {
         $self->pixeldata->[ $y ] = [];
     }
     else {
+        $range->[ 1 ] = @{ $self->pixeldata->[ $y ] } - 1 if $range->[ 1 ] == -1;
         $self->pixeldata->[ $y ]->[ $_ ] = undef
             for $range->[ 0 ] .. $range->[ 1 ];
     }
+}
 
-    $self->width( $y ) if $y > $self->width;
+=head2 delete_line( $y )
+
+Removes the line from the canvas, moving all subsquent lines up.
+
+=cut
+
+sub delete_line {
+    my $self  = shift;
+    my $y     = shift;
+
+    return unless exists $self->pixeldata->[ $y ];
+
+    delete @{ $self->pixeldata }[ $y ];
+    $self->height( $self->height - 1 );
 }
 
 =head2 as_ascii( )
